#! /usr/bin/env python

############################################
# Script to extract the date from a string formatted as xxxxYYYYMMDDnnnx.xxx, where x is any character, 
# YYYY is a 4-digit year, MM is a two-digit month, DD is a two-digit day of month and nnn is any digit 
# Intended for Trimble raw GPS data files.
#
# Author: Ben Taylor
#
# Change history:
# 4th Dec. 2009: Created
#
# You may use or alter this script as you wish, but no warranty of any kind is given - it might be broken, it might
# open horrible security holes if you use it in an insecure environment, and if it does it's your fault not mine.
############################################

import sys
import os.path
import optparse
import re

# Get command-line arguments
usage = "\n%prog [-h] [-q] input_file [input_file] ...\n"
usage = usage + "Extracts the file date from Trimble raw GPS filenames\n"
parser = optparse.OptionParser(usage=usage)
parser.add_option("-q", "--quiet", dest="quiet", action="store_true", default=False, help="If set suppresses error messages")

(options, args) = parser.parse_args()

# Check the user actually gave an argument
if (len(args) < 1):
    print "Must give at least one filename"
    sys.exit(1)
# end if

# For each filename given
for filename in args:

    # Get the filename without the path
    filebase = os.path.basename(filename)
    
    # Try and match the expected date string from the filename
    datematch = re.search(".*(20\d{2})(\d{2})(\d{2})\d{4}\w\..{3}$", filebase)
    
    # If it didn't match, this isn't a string formatted as expected, go on to the next one
    if (datematch == None):
        if (not options.quiet):
            print filename + " is not formatted correctly for date extraction, skipping."
        # end if
        continue
    # end if
    
    # Get the year, month and day from the match
    year = datematch.group(1)
    month = datematch.group(2)
    day = datematch.group (3)
    
    # Print output
    print day + " " + month + " " + year
# end for
